# This scrip retrieves data from internet.

# Load packages into R session
library("quantmod")  
library("tseries")  
library("vars")  

# Data range
date.from <- "1990-01-01"
date.to <- "2020-05-10"

# data0days is a time series (xts) with secondary data from Internet
# Frequency: daily
# #   Variable        Units     Description
# 1   "GSPC"          USD       S&P 500
# 2   "SPY"           USD       SPDR S&P 500 ETF
# 3   "VIX"           Percent   CBOE Volatility Index
# 4   "AAPL"          USD       Apple Inc.
# 5   "IBM"           USD       International Business Machines Corporation
# 6   "DGS3MO"        Percent   3-Month Treasury, constant maturity rate
# 7   "DGS1"          Percent   1-Year Treasury, constant maturity rate
# 8   "DGS5"          Percent   5-Year Treasury, constant maturity rate
# 9   "DGS10"         Percent   10-Year Treasury, constant maturity rate
# 10  "DAAA"          Percent   Moody's Seasoned Aaa Corporate Bond Yield
# 11  "DBAA"          Percent   Moody's Seasoned Baa Corporate Bond Yield 

# Collect historical from Yahoo!
MySymbols <- c("^GSPC", "SPY", "^VIX")
getSymbols(Symbols = MySymbols,  src = "yahoo", from = date.from, to = date.to, periodicity = "daily")
#getSymbols(Symbols = MySymbols,  src = "yahoo", from = date.from, to = date.to, periodicity = "weekly")
#getSymbols(Symbols = MySymbols,  src = "yahoo", from = date.from, to = date.to, periodicity = "monthly")

# Build data structure 0
data0days <- merge(
  GSPC$GSPC.Adjusted,
  SPY$SPY.Close,
  VIX$VIX.Adjusted
  )

# For NA Last Observation Carried Forward
data0days <- na.locf(data0days) 

# Detele NA
data0days<-na.omit(data0days)

# Rename columns
MySymbols <- c(
  "GSPC", "SPY", "VIX"
  )
colnames(data0days) <- paste(MySymbols)


# Create subsets of weeks, months, quartes and years from daily data.
data0weeks <- data0days[xts:::startof(data0days, "weeks")]
data0months <- data0days[xts:::startof(data0days, "months")]
data0quarters <- data0days[xts:::startof(data0days, "quarters")]
data0years <- data0days[xts:::startof(data0days, "years")]


# Delete unused variables
rm("GSPC", "SPY", "VIX")
rm("MySymbols")

# Print data
print(paste("data0days"))
print(dim(data0days))
print(names(data0days))
print(head(data0days))
print(tail(data0days))

print(paste("data0months"))
print(dim(data0months))
print(names(data0months))
print(head(data0months))
print(tail(data0months))

print(paste("data0quarters"))
print(dim(data0quarters))
print(names(data0quarters))
print(head(data0quarters))
print(tail(data0quarters))

# Save the data in R file
save(file="data.RData", list=ls())

