library(shiny)
library(quantmod)
source("GetSymbol.r")

# Global variables
symbols <- c("^GSPC", "SPY", "^VIX", "AAPL")
symbol <<- symbols[1]

date.from <<- as.Date("2000-01-01")
date.to <<- as.Date("2020-01-01")
date.max <<- Sys.Date()
date.min <<- as.Date("1990-01-01")

# User interface
ui <- fluidPage(
  
  textInput(inputId = 'symbol_txt', label = 'Search for symbol', 
            value = symbol, width = NULL, placeholder = NULL),
  
  selectInput(inputId = 'symbol_sel', label = 'Symbol', 
              symbols, selected = symbol),

  dateRangeInput(inputId = 'date_range', label = 'Date range', 
                 start = date.from, end = date.to, separator = " / ",
                 min = date.min, max = date.max),
  
  plotOutput("chart1")

)

# Server
server <- function(input, output) {

  rv <- reactiveValues(data = get_data(symbol, date.from, date.to))
  
  observeEvent(input$symbol_sel, { 
    # Update galobal variable
    symbol <<- input$symbol_sel
    
    # Get data
    rv$data <-get_data(symbol, date.from, date.to)
  }) 
  
  observeEvent(input$date_range, { 
    # Get input vairables
    start <- as.Date(input$date_range[1]) # start
    end <- as.Date(input$date_range[2]) # end
    
    # Date validation
    if (is.na(start)) {
      start <- date.min
    }
    if (is.na(end)) {
      end <- date.max
    }
    if (start >= end) {
      start <- date.min
      end <- date.max
    }

    # Update global variables
    date.from <<- start
    date.to <<- end
    
    # Get data
    rv$data <- get_data(symbol, date.from, date.to)
    
  }) 
  
  output$chart1 <- renderPlot({

    # print(paste("rv$data"))
    # print(dim(rv$data))
    # print(names(rv$data))
    # print(head(rv$data))
    # print(tail(rv$data))
  
    chartSeries(rv$data,
                name = symbol,
                theme = chartTheme('white'))
    
  })
    
}

# Shiny App
shinyApp(ui = ui, server = server)